@@ -1,7 +1,5 @@
 import json
 import logging
-import os.path
-import sys
 import warnings
 
 from .exceptions import (
@@ -328,9 +326,6 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
 
         session = self._requests.Session()
         session.headers.update(headers)
-        verify = self._get_verify()
-        if verify is not None:
-            session.verify = verify
 
         # add retry capabilities
         if hasattr(self._requests, "adapters"):
@@ -473,28 +468,3 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         if d is None:
             return None
         return d.strftime(ISO_DATE_FORMAT)
-
-    def _get_verify(self):
-        """Returns the value for the `verify` parameter of `requests`.
-
-        Three cases are handled:
-
-            - Outside of py2exe this returns `None`. In that case we won't pass
-              in a `verify` argument, thus using `requests` default of `True`.
-            - Inside of py2exe it returns the path to the CA bundle.
-            - If that bundle can't be found it returns `False` to avoid
-              certificate errors.
-
-        This is necessary as the default file from the `requests` module is
-        bundled into the ZIP file and can't be loaded from there.
-
-        For background info see: http://www.py2exe.org/index.cgi/WhereAmI
-        """
-        if not hasattr(sys, "frozen"):
-            # The `frozen` attribute is set in py2exe
-            return None
-        exe_dir = os.path.dirname(sys.executable, sys.getfilesystemencoding())
-        ca_bundle = os.path.join(exe_dir, "cacert", "cacert.pem")
-        if not os.path.exists(ca_bundle):
-            return False
-        return ca_bundle
